==> ra-sdk-0.0.1-20191227.014025-3-sources.jar: com/xdja/ra/bean/RevokeApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:34
 * @Description:
 */
public class RevokeApplyInfo {
    /**
     *必须	申请原因
     */
    private String applyReason;
    /**
     *必须	撤销原因，0-未指明原因；1-末端实体证书私钥泄露；2-CA证书私钥泄露；3-身份信息发生变化；4-证书被更换；5-不再需要证书；6-冻结；7-解冻；8-权限被收回；9-属性中心出现安全问题
     */
    private Integer revokeReason;
    /**
     *必须	申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销
     */
    private Integer applyStatus;
    /**
     *必须	待撤销证书DN
     */
    private String certDn;
    /**
     *必须	待撤销证书的加密证书SN
     */
    private String encSn;
    /**
     *必须	申请创建时间
     */
    private String gmtCreate;
    /**
     *必须	待撤销证书的签名证书SN
     */
    private String signSn;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getRevokeReason() {
        return revokeReason;
    }

    public void setRevokeReason(Integer revokeReason) {
        this.revokeReason = revokeReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    @Override
    public String toString() {
        return "RevokeApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", revokeReason=" + revokeReason +
                ", applyStatus=" + applyStatus +
                ", certDn='" + certDn + '\'' +
                ", encSn='" + encSn + '\'' +
                ", gmtCreate='" + gmtCreate + '\'' +
                ", signSn='" + signSn + '\'' +
                '}';
    }
}

==> ra-sdk-1.0.5-20200922.061634-2-sources.jar: com/xdja/ra/bean/RevokeApplyInfo.java <==
package com.xdja.ra.bean;

/**
 * @author: ggp
 * @Date: 2019/10/22 20:34
 * @Description:
 */
public class RevokeApplyInfo {
    /**
     *必须	申请原因
     */
    private String applyReason;
    /**
     *必须	撤销原因，0-未指明原因；1-末端实体证书私钥泄露；2-CA证书私钥泄露；3-身份信息发生变化；4-证书被更换；5-不再需要证书；6-冻结；7-解冻；8-权限被收回；9-属性中心出现安全问题
     */
    private Integer revokeReason;
    /**
     *必须	申请状态 1:待审核 2:审核未通过 3:待签发 4:签发未通过 5:已签发 6:撤销失败 7:已撤销
     */
    private Integer applyStatus;
    /**
     *必须	待撤销证书DN
     */
    private String certDn;
    /**
     *必须	待撤销证书的加密证书SN
     */
    private String encSn;
    /**
     *必须	申请创建时间
     */
    private String gmtCreate;
    /**
     *必须	待撤销证书的签名证书SN
     */
    private String signSn;
    /**
     *必须	模板名称
     */
    private String tempName;
    /**
     *必须	模板编号
     */
    private String tempNo;
    /**
     *必须	模板扩展参数
     */
    private String tempParas;

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    public Integer getRevokeReason() {
        return revokeReason;
    }

    public void setRevokeReason(Integer revokeReason) {
        this.revokeReason = revokeReason;
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getCertDn() {
        return certDn;
    }

    public void setCertDn(String certDn) {
        this.certDn = certDn;
    }

    public String getEncSn() {
        return encSn;
    }

    public void setEncSn(String encSn) {
        this.encSn = encSn;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getSignSn() {
        return signSn;
    }

    public void setSignSn(String signSn) {
        this.signSn = signSn;
    }

    public String getTempName() {
        return tempName;
    }

    public void setTempName(String tempName) {
        this.tempName = tempName;
    }

    public String getTempNo() {
        return tempNo;
    }

    public void setTempNo(String tempNo) {
        this.tempNo = tempNo;
    }

    public String getTempParas() {
        return tempParas;
    }

    public void setTempParas(String tempParas) {
        this.tempParas = tempParas;
    }

    @Override
    public String toString() {
        return "RevokeApplyInfo{" +
                "applyReason='" + applyReason + '\'' +
                ", revokeReason=" + revokeReason +
                ", applyStatus=" + applyStatus +
                ", certDn='" + certDn + '\'' +
                ", encSn='" + encSn + '\'' +
                ", gmtCreate='" + gmtCreate + '\'' +
                ", signSn='" + signSn + '\'' +
                ", tempName='" + tempName + '\'' +
                ", tempNo='" + tempNo + '\'' +
                ", tempParas='" + tempParas + '\'' +
                '}';
    }
}
